/v1/projects/{project_id}/dynamips/vms/{vm_id}/auto_idlepc — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips vm »

# /v1/projects/{project_id}/dynamips/vms/{vm_id}/auto_idlepc

Contents

- /v1/projects/{project_id}/dynamips/vms/{vm_id}/auto_idlepc
  - GET /v1/projects/{project_id}/dynamips/vms/{vm_id}/auto_idlepc
    - Response status codes

## GET /v1/projects/{project_id}/dynamips/vms/{vm_id}/auto_idlepc

Retrieve the idlepc proposals

### Response status codes

- 200: Best Idle-pc value found
- 400: Invalid request
- 404: Instance doesn’t exist

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips vm »